Version 4.3 - November 2008
Authors: D. Boscher, S. Bourdarie - ONERA-DESP, Toulouse France (Fortran code and IDL wrappers)
T. Guild - The Aerospace Corporation - USA (Fortran code)
Paul O'Brien - The Aerospace Corporation - USA (MATLAB wrappers)
For any questions or to report bugs please contact
Dr. Sebastien Bourdarie or Dr. Daniel Boscher or Dr. Paul O'Brien

The International Radiation Belt Environment Modeling (IRBEM) library is freely distributed under the umbrella of the PRBEM COSPAR panel ( http://cosparhq.cnes.fr/Scistr/Scistr.htm#PRBEM).
In 2003 ONERA-DESP (space environment department) decided to put together a set of source codes into a library dedicated to radiation belt modeling. The toolkit was then called ONERA-DESP-LIB. Because the project has grown along time, and because its development is nowadays more like an international collaborative effort, it has been decided in 2008, after COSPAR 2008 Montreal assembly, to move the library name to IRBEM-LIB (which refers to COSPAR PRBEM panel) and to distribute it under COSPAR PRBEM umbrella (a neutral body).

The following document describes how to use the IRBEM fortran library (formerly the ONERA-DESP library) to compute magnetic coordinates and drift shells using various external magnetic field models. Further routines are provided for various coordinate and time format transformations.

The library can be called from FORTRAN or C code and from IDL or MATLAB code. For IDL and MATLAB wrappers are provided in the distribution package.

The package includes a Makefile to built the library on various platform, install it and test it (See section installation for more details).

Two libraries are created, one for access from IDL or MATLAB and one for access from fortran or some other language.

Notes:

1. The bad value flag is set to -1.d31 throughout.

Rule of use: This library is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version. This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details. You should have received a copy of the GNU Lesser General Public License along with this library. If not, see http://www.gnu.org/licenses/.
COSPAR does not warrant or assume any legal liability or responsibility for the accuracy, completeness, use, or usefulness of any information, apparatus, product, or process disclosed in documents and software available from the IRBEM library or developed as a result of the use of information or software made available from the library.
If you want to fully refer to this library in publications or reports, use the following: "D. Boscher1, S. Bourdarie1, P. O'Brien2, T. Guild2,(1 ONERA-DESP, Toulouse France; 2 Aerospace Corporation, Washington DC, USA), IRBEM library V4.3, 2004-2008".

Acknowledgments: The authors whish to thanks:

- K. Pfitzer, N. Tsyganenko, I. Alexeev and their co-authors for providing us magnetic field model source codes and for good discussions on how to use their model correctly.
- R. Friedel (LANL), Y. Dotan and M. Redding (Aerospace corporation) for good discussions, advices and bug reports which are always very helpfull when one attemps to develop such a tool.
- D. Bilitza for his help regarding the use of IGRF magnetic field model and MSIS models.
- D. Brautigam for providing us CRRES models.
- D. Vallado for providing free of use source code for orbit propagator (SGP4).